"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const Touchable_1 = __importDefault(require("../Touchable"));
const theme_1 = require("../Styles/theme");
const Icon_1 = __importDefault(require("../Icon"));
const ActionSheet = props => {
    const { visible, cancelText = '取消', actions, showCheckStatus = false, checkSize = 24, checkColor = theme_1.Theme.colorTextParagraph, checkIndex, onClose, onClickItem, } = props;
    return (react_1.default.createElement(react_native_1.Modal, { visible: visible, transparent: true, animationType: "slide", statusBarTranslucent: true, onRequestClose: onClose },
        react_1.default.createElement(react_native_1.View, { style: styles.container },
            react_1.default.createElement(react_native_1.View, { style: styles.top }),
            react_1.default.createElement(react_native_1.View, { style: styles.sheet },
                actions.map((item, index) => {
                    const { name, icon, iconSize = 24, subName, color, fontSize, disabled } = item;
                    const showIcon = !!icon;
                    const style = {};
                    color && (style.color = color);
                    fontSize && (style.fontSize = fontSize);
                    return (react_1.default.createElement(Touchable_1.default, { key: index, underlayColor: theme_1.Theme.fillBody, onPress: () => onClickItem(index), disabled: disabled, style: [styles.sheetItem, index === 0 && styles.noBorder] },
                        react_1.default.createElement(react_1.default.Fragment, null,
                            react_1.default.createElement(react_native_1.View, { style: [styles.main, showCheckStatus && styles.mainInLeft] }, showCheckStatus ? (react_1.default.createElement(react_1.default.Fragment, null,
                                react_1.default.createElement(react_native_1.View, { style: styles.checkWrap },
                                    !!showIcon && icon && (react_1.default.createElement(react_native_1.Image, { source: icon, style: [styles.icon, { width: iconSize, height: iconSize }] })),
                                    react_1.default.createElement(react_native_1.Text, { style: [styles.sheetText, disabled && styles.disabledText, style] }, name)),
                                index === checkIndex && react_1.default.createElement(Icon_1.default, { name: "check", size: checkSize, color: checkColor }))) : (react_1.default.createElement(react_1.default.Fragment, null,
                                !!showIcon && icon && (react_1.default.createElement(react_native_1.Image, { source: icon, style: [styles.icon, { width: iconSize, height: iconSize }] })),
                                react_1.default.createElement(react_native_1.Text, { style: [styles.sheetText, disabled && styles.disabledText, style] }, name)))),
                            !!subName && (react_1.default.createElement(react_native_1.View, { style: [styles.sub, showCheckStatus && styles.mainInLeft] },
                                react_1.default.createElement(react_native_1.Text, { style: styles.subText }, subName))))));
                }),
                react_1.default.createElement(Touchable_1.default, { underlayColor: theme_1.Theme.fillBody, onPress: onClose, style: [styles.sheetItem, styles.noBorder, styles.cancel] },
                    react_1.default.createElement(react_native_1.Text, { style: styles.sheetText }, cancelText))))));
};
const styles = react_native_1.StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: theme_1.Theme.fillMask,
    },
    top: {
        flex: 1,
    },
    sheet: {
        backgroundColor: theme_1.Theme.fillBody,
        borderTopLeftRadius: 10,
        borderTopRightRadius: 10,
        overflow: 'hidden',
    },
    sheetItem: {
        justifyContent: 'center',
        borderTopWidth: 0.5,
        paddingVertical: 15,
        backgroundColor: theme_1.Theme.fillBase,
        borderTopColor: theme_1.Theme.borderColor,
    },
    noBorder: {
        borderTopWidth: 0,
    },
    sheetText: {
        fontSize: 15,
        color: theme_1.Theme.colorTextBase,
    },
    disabledText: {
        color: theme_1.Theme.colorTextDisabled,
    },
    main: {
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    mainInLeft: {
        justifyContent: 'space-between',
    },
    checkWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    sub: {
        marginTop: 4,
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    subInLeft: {
        justifyContent: 'flex-start',
    },
    icon: {
        marginRight: 24,
    },
    subText: {
        fontSize: 12,
        color: theme_1.Theme.colorTextSecondary,
    },
    cancel: {
        marginTop: 8,
        alignItems: 'center',
    },
});
exports.default = ActionSheet;
