"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const theme_1 = require("../../components/Styles/theme");
const ANCHOR_SIZE = 50;
const Anchor = props => {
    const { indexList, keyIndex, onChangeIndex } = props;
    const [activeIndex, setActiveIndex] = react_1.useState(-1);
    const [isTouching, setIsTouching] = react_1.useState(false);
    const $container = react_1.useRef(null);
    const listTop = react_1.useRef(0);
    const listHeight = react_1.useRef(0);
    const listItemHeight = react_1.useRef(0);
    const { length } = indexList;
    // 初始化坐标
    react_1.useEffect(() => {
        if ($container.current) {
            $container.current.measureInWindow((x, y, w, h) => {
                // console.log('measure info', y, h);
                // 安卓测量没有包括 StatusBar，修复一下
                let fixHeight = 0;
                if (react_native_1.Platform.OS === 'android') {
                    fixHeight = react_native_1.StatusBar.currentHeight || 0;
                }
                listTop.current = (y || 0) + fixHeight;
                listHeight.current = h || 0;
            });
        }
    }, []);
    // 内容滚动导致标头变化
    react_1.useEffect(() => {
        if (keyIndex >= 0) {
            setActiveIndex(keyIndex);
        }
    }, [keyIndex]);
    // 获取当前滑动到哪个字母
    const getIndexListIndex = (pageY) => {
        // console.log('position', pageY, listTop.current, listHeight.current, listItemHeight.current);
        if (pageY < listTop.current) {
            return -1;
        }
        if (pageY > listTop.current + listHeight.current) {
            return length - 1;
        }
        return Math.floor((pageY - listTop.current) / listItemHeight.current);
    };
    const onTouchStart = (event) => {
        // console.log('touch start', event.nativeEvent.pageY);
        if (!event.nativeEvent.touches.length)
            return;
        setIsTouching(true);
        const currentIndex = getIndexListIndex(event.nativeEvent.pageY);
        setActiveIndex(currentIndex);
        onChangeIndex(currentIndex);
    };
    const onTouchMove = (event) => {
        if (!event.nativeEvent.touches.length)
            return;
        if (!isTouching) {
            setIsTouching(true);
        }
        const currentIndex = getIndexListIndex(event.nativeEvent.pageY);
        setActiveIndex(currentIndex);
        onChangeIndex(currentIndex);
    };
    const onTouchEnd = () => {
        setTimeout(() => {
            setIsTouching(false);
        }, 300);
    };
    const showAnchor = isTouching && activeIndex >= 0;
    const anchorTop = showAnchor
        ? listItemHeight.current * activeIndex + listItemHeight.current / 2 - ANCHOR_SIZE / 2
        : 0;
    return react_1.useMemo(() => {
        return (react_1.default.createElement(react_native_1.View, { style: styles.indexListWrap },
            react_1.default.createElement(react_native_1.View, { ref: $container, removeClippedSubviews: false, style: styles.indexList, onTouchStart: onTouchStart, onTouchMove: onTouchMove, onTouchEnd: onTouchEnd },
                indexList.map((item, index) => {
                    const isActive = activeIndex === index;
                    return (react_1.default.createElement(react_native_1.View, { style: [styles.indexListItem, isActive && styles.activeItem], key: item, onLayout: index === 0 ? event => (listItemHeight.current = event.nativeEvent.layout.height) : undefined },
                        react_1.default.createElement(react_native_1.Text, { style: [styles.indexListItemText, isActive && styles.activeItemText] }, item)));
                }),
                showAnchor && (react_1.default.createElement(react_native_1.View, { style: [styles.anchor, { top: anchorTop }] },
                    react_1.default.createElement(react_native_1.Text, { style: styles.anchorText }, indexList[activeIndex]))))));
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [indexList, activeIndex, showAnchor]);
};
const styles = react_native_1.StyleSheet.create({
    indexListWrap: {
        position: 'absolute',
        right: 0,
        top: 0,
        bottom: 0,
        justifyContent: 'center',
    },
    anchor: {
        position: 'absolute',
        right: 40,
        alignItems: 'center',
        justifyContent: 'center',
        width: ANCHOR_SIZE,
        height: ANCHOR_SIZE,
        borderTopLeftRadius: ANCHOR_SIZE / 2,
        borderTopRightRadius: 0,
        borderBottomLeftRadius: ANCHOR_SIZE / 2,
        borderBottomRightRadius: ANCHOR_SIZE / 2,
        transform: [{ rotate: '45deg' }],
        backgroundColor: theme_1.Theme.fillDisabled,
    },
    anchorText: {
        fontSize: 26,
        color: theme_1.Theme.colorTextBaseInverse,
        transform: [{ rotate: '-45deg' }],
        marginTop: -4,
    },
    indexList: {
        paddingHorizontal: 6,
    },
    indexListItem: {
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        width: 18,
        height: 18,
    },
    indexListItemText: {
        color: theme_1.Theme.colorTextGray,
        fontSize: 11,
    },
    activeItem: {
        backgroundColor: theme_1.Theme.brandPrimary,
        borderRadius: 30,
    },
    activeItemText: {
        color: theme_1.Theme.colorTextBaseInverse,
    },
});
exports.default = Anchor;
