import React from 'react';
import { Modal, StyleSheet, Text, View, Pressable } from 'react-native';
import Touchable from '../Touchable';
import { Theme } from '../Styles/theme';
const ModalHost = props => {
    const { title, content, confirmColor, cancelColor, align = 'left', cancelText = '取消', confirmText = '确定', showCancel = true, mask = true, maskClosable = false, visible, animationType = 'fade', onClose = () => 1, onConfirm = () => 1, } = props;
    return (React.createElement(Modal, { statusBarTranslucent: true, transparent: true, visible: visible, animationType: animationType, onRequestClose: onClose },
        React.createElement(Pressable, { style: [styles.container, mask ? styles.mask : undefined], onPress: () => maskClosable && onClose() },
            React.createElement(Pressable, { style: styles.main, onPress: e => e.stopPropagation() },
                !!title && (React.createElement(View, { style: styles.title },
                    React.createElement(Text, { style: styles.titleText }, title))),
                React.createElement(View, { style: styles.content },
                    React.createElement(Text, { style: [styles.contentText, { textAlign: align }] }, content)),
                React.createElement(View, { style: styles.operation },
                    showCancel && (React.createElement(Touchable, { style: styles.button, onPress: onClose },
                        React.createElement(Text, { style: [styles.cancelText, cancelColor ? { color: cancelColor } : undefined] }, cancelText))),
                    React.createElement(Touchable, { style: [styles.button, showCancel && styles.buttonBorder], onPress: onConfirm },
                        React.createElement(Text, { style: [styles.confirmText, confirmColor ? { color: confirmColor } : undefined] }, confirmText)))))));
};
const styles = StyleSheet.create({
    container: {
        width: '100%',
        height: '100%',
        alignItems: 'center',
        justifyContent: 'center',
    },
    mask: {
        backgroundColor: Theme.fillMask,
    },
    main: {
        width: '80%',
        backgroundColor: Theme.fillBase,
        borderRadius: Theme.radiusMd,
    },
    title: {
        marginTop: Theme.vSpacingLg,
    },
    titleText: {
        textAlign: 'center',
        color: Theme.colorTextBase,
        fontSize: Theme.modalFontSizeHeading,
    },
    content: {
        padding: Theme.hSpacingLg,
    },
    contentText: {
        fontSize: Theme.fontSizeBase,
        color: Theme.colorTextParagraph,
    },
    operation: {
        display: 'flex',
        flexDirection: 'row',
        borderTopColor: Theme.borderColorBase,
        borderTopWidth: Theme.borderWidthSm,
    },
    button: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        height: Theme.modalButtonHeight,
        lineHeight: Theme.modalButtonHeight,
    },
    buttonBorder: {
        borderLeftColor: Theme.borderColorBase,
        borderLeftWidth: Theme.borderWidthSm,
    },
    cancelText: {
        fontSize: Theme.modalButtonFontSize,
        color: Theme.colorTextSecondary,
    },
    confirmText: {
        fontSize: Theme.modalButtonFontSize,
        color: Theme.colorLink,
    },
});
export default ModalHost;
